@@ -41,15 +41,16 @@ setGeneric("initial_transition", function(x, ...)
 	standardGeneric("initial_transition"))
 setGeneric("rare_transitions", function(x, count_threshold, ...) 
 	standardGeneric("rare_transitions"))
-setGeneric("remove_transitions", function(x, from, to) 
+setGeneric("remove_transitions", function(x, from, to, copy=TRUE) 
 	standardGeneric("remove_transitions"))
-setGeneric("remove_selftransitions", function(x) 
+setGeneric("remove_selftransitions", function(x, copy=TRUE) 
 	standardGeneric("remove_selftransitions"))
 
 ## tNN
 setGeneric("cluster", function(x, newdata, ...) standardGeneric("cluster"))
 setGeneric("clusters", function(x) standardGeneric("clusters"))
 setGeneric("cluster_counts", function(x) standardGeneric("cluster_counts"))
+setGeneric("last_clustering", function(x) standardGeneric("last_clustering"))
 setGeneric("cluster_centers", function(x) standardGeneric("cluster_centers"))
 setGeneric("find_clusters", function(x, newdata, ...) 
 	standardGeneric("find_clusters"))
@@ -65,11 +66,11 @@ setGeneric("prune", function(x, ...)
 	standardGeneric("prune"))
 setGeneric("merge_clusters", function(x, to_merge, ...) 
 	standardGeneric("merge_clusters"))
-setGeneric("remove_clusters", function(x, to_remove) 
+setGeneric("remove_clusters", function(x, to_remove, copy=TRUE) 
 	standardGeneric("remove_clusters"))
 
 
-## fixme: make it one recluster method
+## FIXME: make it one recluster method
 setGeneric("recluster_hclust", function(x, ...) 
 	standardGeneric("recluster_hclust"))
 setGeneric("recluster_kmeans", function(x, ...) 
@@ -78,4 +79,6 @@ setGeneric("recluster_pam", function(x, ...)
 	standardGeneric("recluster_pam"))
 setGeneric("recluster_reachability", function(x, ...) 
 	standardGeneric("recluster_reachability"))
+setGeneric("recluster_tNN", function(x, ...) 
+	standardGeneric("recluster_tNN"))
 
